%define major		0
%define	docname		ngspice-doc
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

Summary:	Mixed Mode - Mixed Level Circuit Simulator Based On Berkley's spice3f5
Name:		ngspice
Version:	43
Release:	%mkrel 1
License:	GPLv2 and LGPLv2 and BSD
Group:		System/Libraries
Url:		https://ngspice.sourceforge.io/
Source0:	https://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
Source1:	https://downloads.sourceforge.net/%{name}/%{docname}-%{version}.tar.gz
# https://sourceforge.net/p/ngspice/bugs/679/
# https://sourceforge.net/p/ngspice/ngspice/merge-requests/19/
# misc/string.c: fix one byte ahead access in dup_string
Patch19:	MR19-misc-string.c-fix-one-byte-ahead-access-in-dup_strin.patch

BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(libedit)
BuildRequires:	pkgconfig(readline)
BuildRequires:	pkgconfig(xaw7)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xft)
BuildRequires:	pkgconfig(xmu)

%description
Ngspice is a mixed-level/mixed-signal circuit simulator. Its code is based on
three open source software packages: Spice3f5, Cider1b1 and Xspice. It is the
open source successor of these venerable packages. Many, many modifications,
bug fixes and improvements have been added to the code, yielding a stable and
reliable simulator. Therefore, besides being used as a standalone simulator,
Ngspice has been incorporated into many projects, see our simulation
environments page.

%package -n %{libname}
Summary:	Main library for %{name}
Group:		System/Libraries

Provides:	%{name}-codemodel = %{version}-%{release}

%description -n %{libname}
This package contains the library needed to run programs dynamically
linked with %{name}.

%package -n %{develname}
Summary:	Headers for developing programs that will use %{name}
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}%{major}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains the headers that programmers will need to develop
applications which will use %{name}.

%prep
%autosetup -p1 -a 1

cp -a . %{_builddir}/noshared

%build
# Cannot enable adms due to there licences
# see https://sourceforge.net/p/ngspice/ngspice/ci/master/tree/COPYING
%configure \
	--with-ngshared \
	--enable-klu \
	--enable-xspice \
	--enable-openmp \
	--enable-osdi \
	--enable-predictor \
	--enable-maintainer-mode \
	--with-readline=no \
	--with-editline=yes \
	--enable-cider \
	--disable-adms \
	--disable-debug
%make_build

pushd %{_builddir}/noshared
%configure \
	--without-ngshared \
	--enable-klu \
	--enable-xspice \
	--enable-openmp \
	--enable-osdi \
	--enable-predictor \
	--enable-maintainer-mode \
	--with-readline=yes \
	--enable-cider \
	--disable-adms \
	--disable-debug
%make_build
popd

%install
%make_install -C %{_builddir}/noshared
%make_install

# we don't want these
find %{buildroot} -name "*.la" -delete

%files
%doc AUTHORS NEWS README
%license COPYING
%{_bindir}/ngspice
%dir %{_datadir}/ngspice
%{_datadir}/ngspice/scripts/
%{_mandir}/man1/ngspice.1.xz

%files -n %{libname}
%license COPYING
%{_libdir}/libngspice.so.%{major}{,.*}
%dir %{_libdir}/ngspice
%{_libdir}/ngspice/*

%files -n %{develname}
%{_libdir}/libngspice.so
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/*


%changelog
* Wed Jul 17 2024 daviddavid <daviddavid> 43-1.mga10
+ Revision: 2081956
- new version: 43

* Sat Jul 06 2024 daviddavid <daviddavid> 42-3.mga10
+ Revision: 2080134
- build also as non-shared to get ngspice binary

* Sat Mar 16 2024 daviddavid <daviddavid> 42-2.mga10
+ Revision: 2050090
- enable klu, osdi and predictor support

* Sat Dec 30 2023 daviddavid <daviddavid> 42-1.mga10
+ Revision: 2024435
- new version: 42

* Sun Sep 03 2023 daviddavid <daviddavid> 41-2.mga10
+ Revision: 1983883
- fix owner of lib/ngspice dir
- package some docs

* Sun Sep 03 2023 daviddavid <daviddavid> 41-1.mga10
+ Revision: 1983875
- new version: 41

* Sat Apr 01 2023 daviddavid <daviddavid> 40-1.mga9
+ Revision: 1951137
- new version: 40

* Wed Dec 07 2022 daviddavid <daviddavid> 38-1.mga9
+ Revision: 1918862
- new version: 38
- new version: 34
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Wed Nov 04 2020 daviddavid <daviddavid> 33-1.mga8
+ Revision: 1642653
- new version: 33
- fix owner of data dir

* Sun Sep 13 2020 wally <wally> 32-1.mga8
+ Revision: 1625963
- new version 32
- fix lib pkg name
- drop static devel pkg containing only .la file
- fix description

* Wed Feb 19 2020 umeabot <umeabot> 31-3.mga8
+ Revision: 1542725
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Jan 06 2020 luigiwalser <luigiwalser> 31-2.mga8
+ Revision: 1476813
- rebuild for readline

* Mon Sep 30 2019 zezinho <zezinho> 31-1.mga8
+ Revision: 1448247
- new version 31

* Mon Mar 25 2019 zezinho <zezinho> 30-1.mga7
+ Revision: 1380175
- new version 30

* Sun Sep 23 2018 umeabot <umeabot> 27-2.mga7
+ Revision: 1299742
- Mageia 7 Mass Rebuild

* Tue Apr 03 2018 zezinho <zezinho> 27-1.mga7
+ Revision: 1215004
- explicitly disable  CIDER and adms to ensure they never get enabled with a new upstream default
- imported package ngspice


* Thu Mar 22 2018 Adrien Guichard <guichard.adrien@gmail.com> 27-1.mga7
- Initial Import
